==> redoc-2.0.0-rc.2.jar: META-INF/resources/webjars/redoc/2.0.0-rc.2/typings/common-elements/fields.d.ts <==
export declare const ClickablePropertyNameCell: import("styled-components").StyledComponent<"td", import("../theme").ResolvedThemeInterface, {
    kind?: string | undefined;
}, never>;
export declare const FieldLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypePrefix: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeName: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeTitle: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeFormat: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const RequiredLabel: import("styled-components").StyledComponent<"div", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const RecursiveLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const NullableLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const PatternLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ExampleValue: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ConstraintItem: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;

==> redoc-2.1.5.jar: META-INF/resources/webjars/redoc/2.1.5/typings/common-elements/fields.d.ts <==
export declare const ClickablePropertyNameCell: import("styled-components").StyledComponent<"td", import("../theme").ResolvedThemeInterface, {
    kind?: string | undefined;
}, never>;
export declare const FieldLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypePrefix: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeName: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeTitle: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const TypeFormat: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const RequiredLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {
    as: string;
}, "as">;
export declare const PropertyLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {
    as: string;
}, "as">;
export declare const RecursiveLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const PatternLabel: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ExampleValue: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ExtensionValue: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ConstraintItem: import("styled-components").StyledComponent<"span", import("../theme").ResolvedThemeInterface, {}, never>;
export declare const ToggleButton: import("styled-components").StyledComponent<"button", import("../theme").ResolvedThemeInterface, {}, never>;
